countries.Country (Country) — amici1

# `countries.Country` (Country)

Country(name, isocode, short_code, iso3, name_de, name_fr)

Master tables : countries.Countries (Countries)

Slave tables : contacts.PartnersByCountry (Partners), countries.PlacesByCountry (Places)

Database fields:

- Designation (name) : The designation of this country.

- ISO code (isocode) : The two-letter code for this country as defined by ISO 3166-1. For countries that no longer exist it may be a 4-letter code.

- Short code (short_code) : A short abbreviation for regional usage. Obsolete.

- ISO-3 code (iso3) : The three-letter code for this country as defined by ISO 3166-1.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.countries.models.Country.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.countries.models.Country.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.countries.models.Country.overview`.

Referenced from addresses.Address.country, contacts.Partner.country, countries.Place.country

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
name | Designation | The designation of this country.
isocode | ISO code | The two-letter code for this country as defined by ISO 3166-1. For countries that no longer exist it may be a 4-letter code.
short_code | Short code | A short abbreviation for regional usage. Obsolete.
iso3 | ISO-3 code | The three-letter code for this country as defined by ISO 3166-1.
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |